@@ -36,7 +36,7 @@ class ActionGetCompanyProfile(AbstractAction):
         raw: bool = False,
         session: requests.Session = None,
         logger: logging.Logger = None,
-    ) -> Union[dict, CompanyProfile]:
+    ) -> Union[CompanyProfile, Dict, None]:
         if logger is None:
             logger = cls.build_logger()
         if session is None:
@@ -61,9 +61,9 @@ class ActionGetCompanyProfile(AbstractAction):
             response_dict = response_raw.json()
 
             if raw is True:
-                response = response_dict
+                return response_dict
             else:
-                response = cls.company_profile_to_grpc(
+                return cls.company_profile_to_grpc(
                     payload=response_dict,
                 )
         except Exception as e:
@@ -72,13 +72,11 @@ class ActionGetCompanyProfile(AbstractAction):
             logger.fatal(e)
             return None
 
-        return response
-
     def call(
         self,
         product_isin: str,
         raw: bool = False,
-    ) -> Union[dict, CompanyProfile]:
+    ) -> Union[CompanyProfile, Dict, None]:
         connection_storage = self.connection_storage
         session_id = connection_storage.session_id
         session = self.session_storage.session
