@@ -33,7 +33,7 @@ class ActionGetFinancialStatements(AbstractAction):
         raw: bool = False,
         session: requests.Session = None,
         logger: logging.Logger = None,
-    ) -> Union[dict, FinancialStatements]:
+    ) -> Union[FinancialStatements, Dict, None]:
         if logger is None:
             logger = cls.build_logger()
         if session is None:
@@ -58,9 +58,9 @@ class ActionGetFinancialStatements(AbstractAction):
             response_dict = response_raw.json()
 
             if raw is True:
-                response = response_dict
+                return response_dict
             else:
-                response = cls.financial_statements_to_grpc(
+                return cls.financial_statements_to_grpc(
                     payload=response_dict,
                 )
         except Exception as e:
@@ -69,13 +69,11 @@ class ActionGetFinancialStatements(AbstractAction):
             logger.fatal(e)
             return None
 
-        return response
-
     def call(
         self,
         product_isin: str,
         raw: bool = False,
-    ) -> Union[dict, FinancialStatements]:
+    ) -> Union[FinancialStatements, Dict, None]:
         connection_storage = self.connection_storage
         session_id = connection_storage.session_id
         session = self.session_storage.session
