@@ -55,7 +55,7 @@ class ActionGetOrdersHistory(AbstractAction):
         raw: bool = False,
         session: requests.Session = None,
         logger: logging.Logger = None,
-    ) -> OrdersHistory:
+    ) -> Union[OrdersHistory, Dict, None]:
         """Retrieve history about orders.
         Args:
             request (OrdersHistory.Request):
@@ -105,8 +105,8 @@ class ActionGetOrdersHistory(AbstractAction):
         params["intAccount"] = credentials.int_account
         params["sessionId"] = session_id
 
-        request = requests.Request(method="GET", url=url, params=params)
-        prepped = session.prepare_request(request)
+        http_request = requests.Request(method="GET", url=url, params=params)
+        prepped = session.prepare_request(http_request)
         response_raw = None
 
         try:
@@ -114,9 +114,9 @@ class ActionGetOrdersHistory(AbstractAction):
             response_dict = response_raw.json()
 
             if raw is True:
-                response = response_dict
+                return response_dict
             else:
-                response = cls.orders_history_to_grpc(
+                return cls.orders_history_to_grpc(
                     payload=response_dict,
                 )
         except Exception as e:
@@ -124,13 +124,11 @@ class ActionGetOrdersHistory(AbstractAction):
             logger.fatal(e)
             return None
 
-        return response
-
     def call(
         self,
         request: OrdersHistory.Request,
         raw: bool = False,
-    ) -> Union[dict, OrdersHistory]:
+    ) -> Union[OrdersHistory, Dict, None]:
         connection_storage = self.connection_storage
         session_id = connection_storage.session_id
         session = self.session_storage.session
