@@ -36,7 +36,7 @@ class ActionGetTopNewsPreview(AbstractAction):
         raw: bool = False,
         session: requests.Session = None,
         logger: logging.Logger = None,
-    ) -> Union[dict, TopNewsPreview]:
+    ) -> Union[TopNewsPreview, Dict, None]:
         if logger is None:
             logger = cls.build_logger()
         if session is None:
@@ -60,9 +60,9 @@ class ActionGetTopNewsPreview(AbstractAction):
             response_dict = response_raw.json()
 
             if raw is True:
-                response = response_dict
+                return response_dict
             else:
-                response = cls.top_news_preview_to_grpc(
+                return cls.top_news_preview_to_grpc(
                     payload=response_dict,
                 )
         except Exception as e:
@@ -71,12 +71,10 @@ class ActionGetTopNewsPreview(AbstractAction):
             logger.fatal(e)
             return None
 
-        return response
-
     def call(
         self,
         raw: bool = False,
-    ) -> Union[dict, TopNewsPreview]:
+    ) -> Union[TopNewsPreview, Dict, None]:
         connection_storage = self.connection_storage
         session_id = connection_storage.session_id
         session = self.session_storage.session
