@@ -13,7 +13,6 @@ from degiro_connector.core.abstracts.abstract_action import AbstractAction
 from degiro_connector.trading.models.trading_pb2 import (
     Credentials,
     TransactionsHistory,
-    Update,
 )
 
 
@@ -58,7 +57,7 @@ class ActionGetTransactionsHistory(AbstractAction):
         raw: bool = False,
         session: requests.Session = None,
         logger: logging.Logger = None,
-    ) -> Union[dict, Update]:
+    ) -> Union[TransactionsHistory, Dict, None]:
         """Retrieve history about transactions.
         Args:
             request (TransactionsHistory.Request):
@@ -108,8 +107,8 @@ class ActionGetTransactionsHistory(AbstractAction):
         params["intAccount"] = credentials.int_account
         params["sessionId"] = session_id
 
-        request = requests.Request(method="GET", url=url, params=params)
-        prepped = session.prepare_request(request)
+        http_request = requests.Request(method="GET", url=url, params=params)
+        prepped = session.prepare_request(http_request)
         response_raw = None
 
         try:
@@ -117,9 +116,9 @@ class ActionGetTransactionsHistory(AbstractAction):
             response_dict = response_raw.json()
 
             if raw is True:
-                response = response_dict
+                return response_dict
             else:
-                response = cls.transactions_history_to_grpc(
+                return cls.transactions_history_to_grpc(
                     payload=response_dict,
                 )
         except Exception as e:
@@ -127,13 +126,11 @@ class ActionGetTransactionsHistory(AbstractAction):
             logger.fatal(e)
             return None
 
-        return response
-
     def call(
         self,
         request: TransactionsHistory.Request,
         raw: bool = False,
-    ) -> Union[dict, TransactionsHistory]:
+    ) -> Union[TransactionsHistory, Dict, None]:
         connection_storage = self.connection_storage
         session_id = connection_storage.session_id
         session = self.session_storage.session
